package org.foxarmy.barcodescannerforemployees.views

import android.app.Activity
import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.core.content.ContextCompat
import org.foxarmy.barcodescannerforemployees.DBStorageController
import org.foxarmy.barcodescannerforemployees.R
import org.foxarmy.barcodescannerforemployees.dataclasses.AbstractProduct
import org.foxarmy.barcodescannerforemployees.dataclasses.Product
import org.foxarmy.barcodescannerforemployees.getActivity
import org.foxarmy.barcodescannerforemployees.getImageUri
import java.io.File

class ProductView: LinearLayout {
    var product: Product = Product()
    var isProductSelected = false
    private lateinit var activity: Activity

    private lateinit var productImageView: ImageView
    private lateinit var productNameTextView: TextView
    private lateinit var productNetWeightTextView: TextView
    private lateinit var productAmountTextView: TextView
    private lateinit var productCategoryView: TextView
    private lateinit var productLifeSpan: TextView

    constructor(context: Context, a: AttributeSet) : super(context, a) {
        activity = getActivity(context)!!
        val inflater: LayoutInflater = activity.layoutInflater
        inflater.inflate(R.layout.product_view, this)
    }

    constructor(activity: Activity, context: Context, product: Product) : super(context) {
        this.product = product
        this.activity = activity
        val inflater: LayoutInflater = activity.layoutInflater
        inflater.inflate(R.layout.product_view, this)

        productImageView = findViewById(R.id.productPicture)
        productNameTextView = findViewById(R.id.productNameView)
        productNetWeightTextView = findViewById(R.id.productNetWeightView)
        productAmountTextView = findViewById(R.id.amountView)
        productCategoryView = findViewById(R.id.categoryView)
        productLifeSpan = findViewById(R.id.dateSpan)

        update()
    }

    fun update () {
        val linkedAbstractProduct: AbstractProduct = DBStorageController(activity).findAbstractProductById(DBStorageController(activity).readableDatabase, product.abstractProductId)!!

        val picturesDir = File(activity.filesDir, "pictures")
        picturesDir.mkdirs()
        val pictureFile = File(picturesDir, "${linkedAbstractProduct.imageHash}.png")
        val imageUri = getImageUri(activity, pictureFile)
        productImageView.setImageURI(imageUri)

        productNameTextView.text = linkedAbstractProduct.name
        productNetWeightTextView.text = linkedAbstractProduct.netWeight.toString()
        productAmountTextView.text = product.amount.toString()
        productCategoryView.text = DBStorageController(activity).getCategoryNameById(DBStorageController(activity).readableDatabase, linkedAbstractProduct.category)
        productLifeSpan.text = "${product.dateOfProduction}-${product.dateOfExpiry}"

        this.background = ContextCompat.getDrawable(context, if (isProductSelected) R.drawable.outline_selected else R.drawable.outline)
        

        findViewById<ConstraintLayout>(R.id.productLayout).setOnLongClickListener {
            isProductSelected = !isProductSelected
            this.background = ContextCompat.getDrawable(context, if (isProductSelected) R.drawable.outline_selected else R.drawable.outline)
            true
        }
    }
}